@@ -6,9 +6,9 @@ cowbuilderroot="/home/neurodebian"
 buildplace="${cowbuilderroot}/build"
 
 # all currently supported dists
-allnddists="nd+debian-squeeze nd+debian-wheezy nd+debian-jessie nd+debian-stretch nd+debian-sid \
-            nd+ubuntu-lucid nd+ubuntu-precise nd+ubuntu-trusty nd+ubuntu-utopic nd+ubuntu-vivid"
-alldists="$allnddists debian-squeeze debian-wheezy debian-jessie debian-stretch debian-sid"
+allnddists="nd+debian-wheezy nd+debian-jessie nd+debian-stretch nd+debian-sid \
+            nd+ubuntu-precise nd+ubuntu-trusty nd+ubuntu-vivid nd+ubuntu-wily nd+ubuntu-xenial"
+alldists="$allnddists debian-wheezy debian-jessie debian-stretch debian-sid"
 
 # default is debian
 aptcache="${cowbuilderroot}/debian_aptcache"
